
DEFAULT_LICENSE = "CC BY-SA 4.0"
DEFAULT_ATTRIBUTION = "Created by thedailydialectics for educational purposes"

# ------------------------------------------------------------------
# Environment keys (override in ~/.bashrc, .env, or systemd)
# ------------------------------------------------------------------
BASE_DIR_KEY_PROD   = "HUGPY_BASE_DIR_SUMMARY_GENERATOR_FAST_PROD"
BASE_DIR_KEY_SERVER = "HUGPY_BASE_DIR_SUMMARY_GENERATOR_FAST_SERVER"
BASE_DIR_KEY_LOCAL  = "HUGPY_BASE_DIR_SUMMARY_GENERATOR_FAST_LOCAL"

# ------------------------------------------------------------------
# Defaults
# ------------------------------------------------------------------
SUMMARY_WORDS  = 150
CHARS_LIMIT    = 2000
SUMMARY_DIR    = "summaries"
MANIFEST_NAME  = "manifest.json"
